# Smart Citizen Connector

This is a simple connector written in `python` to get data from the Smart Citizen API. It is only providing this functionality, to be used in conjunction with other scripts, and it does not aim to replace [scdata](https://github.com/fablabbcn/smartcitizen-data), which is a much more advanced data analysis framework.

## Installation

Simply do:

```
pip install smartcitizen-connector
```

### Development

Or clone the repo and install in editable mode:

```
git clone git@github.com:fablabbcn/smartcitizen-connector.git
cd smartcitizen-connector
pip install -e .
```
